/*!
  \file
  \brief セルのプレビュー表示ウィジット

  \author Satofumi KAMIMURA

  $Id: CellPreviewWidget.cpp 261 2009-01-22 06:48:10Z satofumi $
*/

#include "CellPreviewWidget.h"


struct CellPreviewWidget::pImpl
{
  // !!!
};


CellPreviewWidget::CellPreviewWidget(QWidget* parent)
  : QWidget(parent), pimpl(new pImpl)
{
  // !!!
}


CellPreviewWidget::~CellPreviewWidget(void)
{
}
